netapp_ontap.models.dcn_hardware API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.dcn_hardware`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DcnHardwareSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DcnHardware object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `board: str GET`

    Type of the system board, defined by the vendor.

    Example: System Board XXVIII

  `cpu: DcnHardwareCpu GET`

    CPU information.

  `frus: List[DcnFru] GET`

    The field replaceable units (FRUs) on the node.

  `gpu: DcnHardwareGpu GET`

    GPU information.